### 0.8.0

```{rubric} Features
```

* added support for {func}`~rapids_singlecell.tl.umap` {pr}`47` {smaller}`S Dicks`
* added support for `neighbors` {pr}`50` {smaller}`S Dicks`


```{rubric} Bug fixes
```

* Fixed {func}`~rapids_singlecell.pp.filter_highly_variable` {pr}`51` {smaller}`S Dicks`
